@@ -9,30 +9,6 @@
 #include <getopt.h>
 #include <unistd.h>
 
-#define SET_HASH_CHECK_MODE \
-{\
-	switch(optarg[0])\
-	{\
-	case '1':\
-		oparg->CHECK_MODE = BEFORE;\
-		break;\
-\
-	case '2':\
-		oparg->CHECK_MODE = AFTER;\
-		break;\
-\
-	case '0':	/* コンペアを行わない */\
-		oparg->CHECK = NOT;\
-		oparg->CHECK_MODE = NOT;\
-		break;\
-\
-	default:\
-		fprintf(stderr, "コンペアモードの指定値が正しくありません\n");\
-		exit(EXIT_FAILURE);\
-		break;\
-	}\
-}
-
 /* 関数プロトタイプ */
 void analyze_argument(const int argc, char **argv, OPArg *oparg);
 
@@ -141,7 +117,26 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 			}
 			oparg->CHECK = V_FIVE;
 
-			SET_HASH_CHECK_MODE
+			switch(optarg[0])
+			{
+			case '1':
+				oparg->CHECK_MODE = BEFORE;
+				break;
+
+			case '2':
+				oparg->CHECK_MODE = AFTER;
+				break;
+
+			case '0':	/* コンペアを行わない */
+				oparg->CHECK = NOT;
+				oparg->CHECK_MODE = NOT;
+				break;
+
+			default:
+				fprintf(stderr, "コンペアモードの指定値が正しくありません\n");
+				exit(EXIT_FAILURE);
+				break;
+			}
 			break;
 
 		case 't':	/* スレッドモード */
