@@ -2,6 +2,7 @@
 #define DO_COMPARE_VERIFY_ONE_H
 
 #include "print_error.h"
+#include "remove_source_rmdir.h"
 #include "remove_source_unlink.h"
 #include "struct_CPDD.h"
 #include "struct_CPInfo.h"
@@ -28,6 +29,17 @@ static inline void compare_verify_two(const OPArg *oparg, const VList *file_list
 	 */
 	VList *tmp = (VList *)file_list;
 
+	_Bool is_move;
+
+	if(oparg->M == MOVE)
+	{
+		is_move = true;
+	}
+	else
+	{
+		is_move = false;
+	}
+
 	for(;;)
 	{
 		CPInfo *cpinfo = (CPInfo *)tmp->data;
@@ -37,11 +49,11 @@ static inline void compare_verify_two(const OPArg *oparg, const VList *file_list
 			switch(oparg->CHECK)
 			{
 			case V_FIVE:
-				if((cpinfo->src_md5 != NULL) && (cpinfo->dst_size > 0) && (cpinfo->dst_para == WRITE))
+				if((cpinfo->src_md5 != NULL) && (cpinfo->dst_para == WRITE))
 				{
 					verify_hash(oparg, sdir, cpinfo, cpdd);
 
-					if((oparg->M == MOVE) && (cpinfo->hash_check == true))
+					if(is_move && (cpinfo->hash_check == true))
 					{
 						REMOVE_SOURCE_UNLINK
 					}
@@ -53,6 +65,14 @@ static inline void compare_verify_two(const OPArg *oparg, const VList *file_list
 				break;
 			}
 		}
+		else if(cpinfo->is_rmdir && is_move && ((cpinfo->dst_para == WRITE) || (cpinfo->dst_para == SKIP)))
+		{
+			REMOVE_SOURCE_RMDIR
+		}
+		else if((cpinfo->src_type == SYMBOLICLINK) && is_move && (cpinfo->dst_para == WRITE))
+		{
+			REMOVE_SOURCE_UNLINK
+		}
 
 		if(tmp->next == NULL)
 		{
