@@ -8,13 +8,14 @@
 
 #include <errno.h>
 
-static inline void print_error(const char *func, const char *file, const int line, CPDD *cpdd);
+static void print_error(const char *func, const char *file, const int line, CPDD *cpdd);
 
 /*******************************************************************************
 *******************************************************************************/
-static inline void print_error(const char *func, const char *file, const int line, CPDD *cpdd)
+static void print_error(const char *func, const char *file, const int line, CPDD *cpdd)
 {
 	printf("%s : %d行\n", file, line);
+
 	if(strcmp(func, "NODATA") != 0)
 	{
 		perror(func);
