@@ -46,7 +46,13 @@ int main(int argc, char **argv)
 			help();
 			return EXIT_SUCCESS;
 		}
-		/* --helpの場合もヘルプを表示する */
+		/* --hの場合もヘルプを表示する */
+		else if((tmp[0] == '-') && (tmp[1] == '-') && (tmp[2] == 'h') && (tmp[3] == '\0'))
+		{
+			help();
+			return EXIT_SUCCESS;
+		}
+		/* --helpの場合でもヘルプを表示する */
 		else if((tmp[0] == '-') && (tmp[1] == '-') && (tmp[2] == 'h') && (tmp[3] == 'e') && (tmp[4] == 'l') && (tmp[5] == 'p'))
 		{
 			help();
