@@ -9,7 +9,7 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-#define INPUT_CHECK_CLEAN \
+#define INPUT_AND_CLEAN \
 {\
 	if(fgets(stdin_buf, INPUT_LEN, stdin) == NULL)\
 	{\
@@ -19,8 +19,15 @@
 	clean(stdin_buf, INPUT_LEN);\
 }
 
+#define MIN_BUF_SIZE 2
+
 /* 関数プロトタイプ */
 void write_conf(const SDir *sdir);
+static _Bool is_enabled_option(char stdin_buf[], const int INPUT_LEN, const char option);
+static char set_hash_check_mode(char stdin_buf[], const int INPUT_LEN);
+static int change_buffer_size(char stdin_buf[], const int INPUT_LEN);
+static char change_overwrite_mode(char stdin_buf[], const int INPUT_LEN);
+static char change_thread_mode(char stdin_buf[], const int INPUT_LEN);
 static void clean(const char stdin_buf[], const int INPUT_LEN);
 static void fgets_is_null(void);
 static void write_error(const char *mes);
@@ -33,214 +40,58 @@ void write_conf(const SDir *sdir)
 	const int INPUT_LEN = 256;
 	char stdin_buf[INPUT_LEN];
 
-	_Bool is_verify = false;
-	char hash_check_mode = '@';
-	_Bool is_hash_check_log = false;
-
-	int buffer_size = 0;
-
-	_Bool is_info = false;
-	_Bool is_overwrite = false;
-	char write_mode = '@';
-	_Bool is_delete = false;
-
-	_Bool is_thread = false;
-	char thread_mode = '@';
-
-	_Bool is_view = false;
-
 	puts("設定の変更を行います");
 
+	_Bool is_verify = is_enabled_option(stdin_buf, INPUT_LEN, 'r');
+
+	char hash_check_mode = '\0';
+	_Bool is_hash_save = false;
+
+	if(is_verify == true)
 	{
-		puts("");
-		puts("ファイルコピー後にベリファイを行いますか?");
-		printf("(y / n) :");
-		fflush(stdout);
-
-		INPUT_CHECK_CLEAN
-
-		if(stdin_buf[0] == 'y')
-		{
-			is_verify = true;
-
-			puts("");
-			puts("ベリファイモードを選んでください");
-			puts("1 : コピー直後にベリファイ");
-			puts("2 : 全コピー終了後に一括ベリファイ");
-			printf("(1 / 2) :");
-			fflush(stdout);
-
-			INPUT_CHECK_CLEAN
-
-			if((stdin_buf[0] == '1') || (stdin_buf[0] == '2'))
-			{
-				hash_check_mode = stdin_buf[0];
-
-				puts("");
-				puts("ベリファイのログを保存しますか?");
-				printf("(y / n) :");
-				fflush(stdout);
-
-				INPUT_CHECK_CLEAN
-
-				if(stdin_buf[0] == 'y')
-				{
-					is_hash_check_log = true;
-				}
-			}
-			else
-			{
-				is_verify = false;
-				puts("ベリファイオプションを無効にします");
-				fflush(stdout);
-			}
-		}
+		hash_check_mode = set_hash_check_mode(stdin_buf, INPUT_LEN);
+		is_hash_save = is_enabled_option(stdin_buf, INPUT_LEN, 'l');
 	}
 
+	_Bool is_buffer_size = is_enabled_option(stdin_buf, INPUT_LEN, 'b');
+	int buffer_size = 0;
+
+	if(is_buffer_size == true)
 	{
-		puts("");
-		puts("バッファのサイズを変更しますか? (初期値は32MB)");
-		printf("(y / n) :");
-		fflush(stdout);
-
-		INPUT_CHECK_CLEAN
-
-		if(stdin_buf[0] == 'y')
-		{
-			puts("数値を入力してください");
-			printf(" :");
-			fflush(stdout);
-
-			INPUT_CHECK_CLEAN
-
-			char *endptr = NULL;
-			buffer_size = (int)strtol(stdin_buf, &endptr, 10);
-	
-			if(buffer_size < 2)
-			{
-				buffer_size = 2;
-			}
-		}
+		buffer_size = change_buffer_size(stdin_buf, INPUT_LEN);
 	}
 
+	_Bool is_info = is_enabled_option(stdin_buf, INPUT_LEN, 'i');
+	_Bool is_overwrite = false;
+
+	if(is_info != true)
 	{
-		puts("");
-		puts("ファイルを上書きする前に確認しますか?");
-		printf("(y / n) :");
-		fflush(stdout);
-
-		INPUT_CHECK_CLEAN
-
-		if(stdin_buf[0] == 'y')
-		{
-			is_info = true;
-		}
+		is_overwrite = is_enabled_option(stdin_buf, INPUT_LEN, 'w');
 	}
 
-	if(is_info == false)
+	char write_mode = '\0';
+
+	if(is_overwrite == true)
 	{
-		puts("");
-		puts("上書きモードを変更しますか? (初期設定は、サイズ又は日付が異なる場合に上書き)");
-		printf("(y / n) :");
-		fflush(stdout);
-
-		INPUT_CHECK_CLEAN
-
-		if(stdin_buf[0] == 'y')
-		{
-			is_overwrite = true;
-
-			puts("");
-			puts("上書きモードを選んでください");
-			puts("1 : 初期設定");
-			puts("2 : 日付が新しい場合に上書き");
-			puts("3 : 常に上書き");
-			puts("0 : 上書きしない");
-			printf("(1 / 2 / 3 / 0) :");
-			fflush(stdout);
-
-			INPUT_CHECK_CLEAN
-
-			if((stdin_buf[0] == '1') || (stdin_buf[0] == '2') || (stdin_buf[0] == '3') || (stdin_buf[0] == '0'))
-			{
-				write_mode = stdin_buf[0];
-			}
-			else
-			{
-				is_overwrite = false;
-				puts("上書きモードを初期設定にします");
-				fflush(stdout);
-			}
-		}
+		write_mode = change_overwrite_mode(stdin_buf, INPUT_LEN);
 	}
 
+	_Bool is_delete = is_enabled_option(stdin_buf, INPUT_LEN, 'm');
+	_Bool is_thread = is_enabled_option(stdin_buf, INPUT_LEN, 't');
+
+	char thread_mode = '\0';
+
+	if(is_thread == true)
 	{
-		puts("");
-		puts("移動モード (ファイルコピー後、元ファイルを削除) に設定しますか?");
-		printf("(y / n) :");
-		fflush(stdout);
-
-		INPUT_CHECK_CLEAN
-
-		if(stdin_buf[0] == 'y')
-		{
-			is_delete = true;
-		}
+		thread_mode = change_thread_mode(stdin_buf, INPUT_LEN);
 	}
 
-	{
-		puts("");
-		puts("スレッドモードを指定しますか? (初期設定は自動判別)");
-		printf("(y / n) :");
-		fflush(stdout);
-
-		INPUT_CHECK_CLEAN
-
-		if(stdin_buf[0] == 'y')
-		{
-			is_thread = true;
-
-			puts("");
-			puts("モードを選んでください (初期設定は自動判別)");
-			puts("1 : 常に同一ドライブモード");
-			puts("2 : 常に別ドライブモード");
-			puts("0 : 初期設定");
-			printf("(1 / 2 / 0) :");
-			fflush(stdout);
-
-			INPUT_CHECK_CLEAN
-
-			if((stdin_buf[0] == '1') || (stdin_buf[0] == '2') || (stdin_buf[0] == '0'))
-			{
-				thread_mode = stdin_buf[0];
-			}
-			else
-			{
-				is_thread = false;
-				puts("スレッドモードを初期設定にします");
-				fflush(stdout);
-			}
-		}
-	}
-
-	{
-		puts("");
-		puts("コピー中のファイル名を表示しますか?");
-		printf("(y / n) :");
-		fflush(stdout);
-
-		INPUT_CHECK_CLEAN
-
-		if(stdin_buf[0] == 'y')
-		{
-			is_view = true;
-		}
-	}
+	_Bool is_view = is_enabled_option(stdin_buf, INPUT_LEN, 'v');
 
 	/* 設定をファイルに保存する */
 	if(
 		(true == is_verify) ||
-		(0 < buffer_size) ||
+		(MIN_BUF_SIZE <= buffer_size) ||
 		(true == is_info) ||
 		(true == is_overwrite) ||
 		(true == is_delete) ||
@@ -309,7 +160,7 @@ void write_conf(const SDir *sdir)
 				printf("ベリファイモード : %c\n", hash_check_mode);
 			}
 
-			if(is_hash_check_log == true)
+			if(is_hash_save == true)
 			{
 				if(
 					(fputs("l", config) == EOF) ||
@@ -324,7 +175,7 @@ void write_conf(const SDir *sdir)
 				puts("ベリファイ/コンペアのログを保存する");
 			}
 
-			if(buffer_size > 0)
+			if(MIN_BUF_SIZE <= buffer_size)
 			{
 				char tmp[INPUT_LEN];
 				sprintf(tmp, "%d", buffer_size);
@@ -432,7 +283,7 @@ void write_conf(const SDir *sdir)
 			}
 
 			fclose(config);
-			chmod(SNOWCP_CONF, 0777);
+			chmod(SNOWCP_CONF, 0666);
 		}
 		else
 		{
@@ -444,28 +295,187 @@ void write_conf(const SDir *sdir)
 	}
 	else
 	{
+		if(chdir(sdir->user_settings_dir) != 0)
+		{
+			fprintf(stderr, "設定フォルダにアクセスできませんでした\n");
+			fprintf(stderr, "強制終了します\n");
+			exit(EXIT_FAILURE);
+		}
+
 		fprintf(stderr, "設定ファイルを削除します\n");
 		unlink(SNOWCP_CONF);
 	}
 }
 
+/*******************************************************************************
+*******************************************************************************/
+static _Bool is_enabled_option(char stdin_buf[], const int INPUT_LEN, const char option)
+{
+	puts("");
+
+	switch(option)
+	{
+	case 'b':
+		puts("バッファのサイズを変更しますか? (初期値は32MB)");
+		break;
+
+	case 'i':
+		puts("ファイルを上書きする前に確認しますか?");
+		break;
+
+	case 'l':
+		puts("ベリファイのログを保存しますか?");
+		break;
+
+	case 'm':
+		puts("移動モード (ファイルコピー後、元ファイルを削除) に設定しますか?");
+		break;
+
+	case 'r':
+		puts("ファイルコピー後にベリファイを行いますか?");
+		break;
+
+	case 't':
+		puts("スレッドモードを指定しますか? (初期設定は自動判別)");
+		break;
+
+	case 'w':
+		puts("上書きモードを変更しますか? (初期設定は、サイズ又は日付が異なる場合に上書き)");
+		break;
+
+	case 'v':
+		puts("コピー中のファイル名を表示しますか?");
+		break;
+
+	default:
+		puts("");
+		break;
+	}
+
+	printf("(y / n) :");
+	fflush(stdout);
+
+	INPUT_AND_CLEAN
+
+	return (stdin_buf[0] == 'y') ? true : false;
+}
+
+/*******************************************************************************
+*******************************************************************************/
+static char set_hash_check_mode(char stdin_buf[], const int INPUT_LEN)
+{
+	while(true)
+	{
+		puts("");
+		puts("ベリファイモードを選んでください");
+		puts("1 : コピー直後にベリファイ");
+		puts("2 : 全コピー終了後に一括ベリファイ");
+		printf("(1 / 2) :");
+		fflush(stdout);
+
+		INPUT_AND_CLEAN
+
+		if(stdin_buf[0] == '1' || stdin_buf[0] == '2')
+		{
+			break;
+		}
+	}
+
+	return stdin_buf[0];
+}
+
+/*******************************************************************************
+*******************************************************************************/
+static int change_buffer_size(char stdin_buf[], const int INPUT_LEN)
+{
+	puts("");
+	puts("数値を入力してください");
+	printf(" :");
+	fflush(stdout);
+
+	INPUT_AND_CLEAN
+
+	char *endptr = NULL;
+	int buffer_size = (int)strtol(stdin_buf, &endptr, 10);
+
+	if(buffer_size < 2)
+	{
+		buffer_size = MIN_BUF_SIZE;
+	}
+
+	return buffer_size;
+}
+
+/*******************************************************************************
+*******************************************************************************/
+static char change_overwrite_mode(char stdin_buf[], const int INPUT_LEN)
+{
+	while(true)
+	{
+		puts("");
+		puts("上書きモードを選んでください");
+		puts("1 : 初期設定");
+		puts("2 : 日付が新しい場合に上書き");
+		puts("3 : 常に上書き");
+		puts("0 : 上書きしない");
+		printf("(1 / 2 / 3 / 0) :");
+		fflush(stdout);
+
+		INPUT_AND_CLEAN
+
+		if((stdin_buf[0] == '1') || (stdin_buf[0] == '2') || (stdin_buf[0] == '3') || (stdin_buf[0] == '0'))
+		{
+			break;
+		}
+	}
+
+	return stdin_buf[0];
+}
+
+/*******************************************************************************
+*******************************************************************************/
+static char change_thread_mode(char stdin_buf[], const int INPUT_LEN)
+{
+	while(true)
+	{
+		puts("");
+		puts("モードを選んでください (初期設定は自動判別)");
+		puts("1 : 常に同一ドライブモード");
+		puts("2 : 常に別ドライブモード");
+		puts("0 : 初期設定");
+		printf("(1 / 2 / 0) :");
+		fflush(stdout);
+
+		INPUT_AND_CLEAN
+
+		if((stdin_buf[0] == '1') || (stdin_buf[0] == '2') || (stdin_buf[0] == '0'))
+		{
+			break;
+		}
+	}
+
+	return stdin_buf[0];
+}
+
 /*******************************************************************************
  * 入力バッファのクリア
 *******************************************************************************/
 static void clean(const char stdin_buf[], const int INPUT_LEN)
 {
 	/* バッファチェック */
-	int a = 0;
+	_Bool check = false;
+
 	for(int i = 0; i < INPUT_LEN; i++)
 	{
 		if(stdin_buf[i] == '\n')
 		{
-			a++;
+			check = true;
 			break;
 		}
 	}
+
 	/* 入力バッファの掃除 */
-	if(a == 0)
+	if(check == false)
 	{
 		while(getchar() != '\n');
 	}
